# Whatify_Toolkit
Welcome to Whatify Toolkit

## Installation:

`pip3 install toolkit_w`
`pip3 install pytest`
`pip3 install allure-pytest`
`pip3 install s3fs`
`pip3 install toolkit_w`

## Usage:

```
import toolkit_w as my_tool

myWhatify = my_tool.MyWhatify()

myWhatify.authenticate(USER, PASSWORD)

```
